tdggraph-package: tdggraph: Simple ggplot2 graphics for depth profiles in...

Description Author(s)

Description

Limnology and oceanography frequently collect data along vertical profiles from the water's surface to depth. 'tdggraph' provides functions built on 'ggplot2' to produce graphics that handle profile data sets, especially depth profile data collected repeatedly at the same location.

Author(s)

Maintainer: Curtis Bohlen curtis.bohlen@maine.edu


ccb60/tdggraph documentation built on Dec. 19, 2021, 1:58 p.m.