Description Usage Format Details Source
A dataset containing vertical profile data collected by automated water quality sonde by Maine's Department of Environmental Protection staff. Data has been filtered down to only include data from one site and one year. Currently, the data is from Site "FR09", just outside the mouth of the Fore River, from 2018. The site and year may change between versions of this package.
1 |
A data frame with 108 rows and 16 variables:
Site Code. A unique character string for different locations. Retained her for documentation purposes, but will include only one value.
Date of sample collection (as and R Date).
Month of sample collection, as a factor. Uses three letter codes.
Time of sample collection, as an R hms object.
Depth of readings, in meters.
Water temperature (C).
Salinity in "Practical Salinity Units" (roughly PPT).
pH value, measured with a electrochemical pH meter, thus on the "NBS" scale. This value can differ from the "Total" pH scale often used in ocean acidification research. See, for example, Pimenta and Greer. 2018. Guidelines for measuring changes in pH and associated carbonate chemistry in coastal environments of the Eastern United States. Atlantic Ecology Division, National Health and Environmental Effects Research Laboratory, US Environmental Protection Agency, Narragansett, RI. EPA/600/R-17/483 available at http://necan.org/sites/default/files/EPA600_R17_483coastalAcidificationMonitoringGuidelinesFinal%20041318%20%282%29_0.pdf.
Oxygen percent saturation.
Dissolved oxygen (mg/l).
Chlorophyll a, (mg/l), measured by a fluorometer. All data is marked with data quality flags as "estimate". For high accuracy work, in situ flourometric analysis of chlorophyll should be calibrated after data collection against laboratory chlorophyll values. These data reflect only the uncorrected field estimates.
Turbidity measurements or detection limits (NTU).
True / False. Was this turbidity measurement below
detection? If so, the value in turbidity is the detection limit.
Data includes temperature, salinity, dissolved oxygen, pH, chlorophyll A and turbidity. Data was collected by lowering automated water quality sensor apparatus from a boat. As the device is lowered, it periodically collects data on depth and water quality parameters. Lack of discrete samples to calibrate optical estimates of chlorophyll A mean the chlorophyll data should be treated as provisional.
Maine Department of Environmental Protection, via Casco Bay Estuary Partnership's (CBEP) 2020 State of Casco Bay Report. Original data received by CBEP from Angie Brewer, Marine Scientist for Maine DEP in response to a request for data to be used in the 2020 State of Casco Bay Report. CBEP staff reviewed, simplified and reorganized the data while preparing the report. Additional information on the report and associated data and data analysis archives are available on the CBEP web site at https://cascobayestuary.org.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.