Description Usage Arguments Value Examples
Interpolates from a series of depth profiles, taken at different dates, times, or locations, and generates a smoothed bivariate time/location (x axis) by depth (y axis, reversed) plot using linear interpolation. Values of the variable being plotted are symbolized by color.
1 2 3 4 5 6 7 8 9 10 |
.dt |
Data frame containing data to plot. Can be NULL, if all data vectors are found in the enclosing environment. |
.x |
Value that defines the x (time) coordinate of the plot. Usually a date or other time coordinate. Can be either a vector or the name of a vector in source data frame, not an expression. |
.y |
Value that defines the (reversed) y coordinate of the plot. Usually the depth. Can be either a numeric vector or the name of a numeric vector in source data frame, not an expression. |
.val |
Value to be symbolized via the color of the dots. Usually a measured environmental variable that varies with water depth. Can be either a numeric vector or the name of a numeric vector in source data frame, not an expression. |
.res_x |
Resolution for the plot, in the x, or time dimension. |
.res_y |
Resolution for the plot in the y or depth dimension. |
y_grow_grid |
TRUE/FALSE should the grid be expanded to integer depths? |
y_with_zero |
TRUE/FALSE should the grid include depth = 0? |
A ggplot object (S3 class defined by ggplot2)
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.