Limnology and oceanography frequently collect data along vertical profiles from the water's surface to depth. 'tdggraph' provides functions built on 'ggplot2' to produce graphics that handle profile data sets, especially depth profile data collected repeatedly at the same location.
Maintainer: Curtis Bohlen curtis.bohlen@maine.edu
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.